using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations.Schema;
using System.Data.Entity;

namespace EntityContext.Core
{
    public abstract class EntityBase
    {
        public Guid Id { get; set; }

        public Guid GetIdentity()
        {
            return this.Id;
        }

        public abstract void Register(DbModelBuilder builder);

        protected virtual void Register<T>(DbModelBuilder builder, string tableName) where T : EntityBase
        {
            builder.Entity<T>().ToTable(tableName);
            builder.Entity<T>().HasKey(e => e.Id);
            builder.Entity<T>().Property(e => e.Id).HasDatabaseGeneratedOption(DatabaseGeneratedOption.Identity);
        }

        public virtual void Seed(ContextBase context)
        {
            if (context == null) { throw new ArgumentNullException("context"); }
        }

        public virtual void AddConstraint(ICollection<string> constraints)
        {
            if (constraints == null) { throw new ArgumentNullException("constraints"); }
        }
    }
}