﻿using System.Data.Entity;
using EntityContext.Core;
using PasswordHash;

namespace EntityContext.Test.Entities
{
    public class User : EntityBase
    {
        public string Username { get; set; }

        public string FirstName { get; set; }

        public string LastName { get; set; }

        public string Email { get; set; }

        public string Password { get; set; }

        public override void Register(DbModelBuilder builder)
        {
            base.Register<User>(builder, "Test.Users");
            builder.Entity<User>().Property(e => e.Username).HasMaxLength(60).IsRequired();
            builder.Entity<User>().Property(e => e.Email).HasMaxLength(128).IsRequired();
            builder.Entity<User>().Property(e => e.Password).HasMaxLength(128).IsRequired();
        }

        public override void AddConstraint(System.Collections.Generic.ICollection<string> constraints)
        {
            constraints.Add("ALTER TABLE [Test].[Users] ADD CONSTRAINT [Unique_EMail] UNIQUE([Email])");
        }

        public override void Seed(ContextBase context)
        {
            var user = new User
            {
                Username = "firsblogger",
                FirstName = "Adam",
                LastName = string.Empty,
                Email = Encrypt.SHA512("adam@edem.com"),
                Password = Encrypt.SHA512("I love Eva!")
            };

            var modelContext = context as ModelContext;
            if (modelContext != null)
            {
                modelContext.Users.Add(user);
            }
        }

        public override string ToString()
        {
            return string.Format("{0} ({1} {2})", this.Username, this.FirstName, this.LastName);
        }
    }
}